/// <reference types="node" />
import express from "express";
import type { Handler, Document } from "openapi-backend";
import type { SimulationStore, ExtendSimulationActionsInput, ExtendSimuationActions } from "./store";
import type { ExtendSimulationSchemaInput, ExtendSimulationSchema } from "./store/schema";
import type { RecursivePartial } from "./store/types";
import type { Context as OpenAPIBackendContext } from "openapi-backend";
import type { Request as ExpressRequest, Response as ExpressResponse } from "express";
type SimulationHandlerFunctions = (context: OpenAPIBackendContext, request: ExpressRequest, response: ExpressResponse) => void;
export type SimulationHandlers = Record<string, SimulationHandlerFunctions>;
export type { ExtendSimuationActions, ExtendSimulationSchema, SimulationStore };
export type { AnyState } from "starfx";
export declare function createFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions>({ port, openapi, extendStore, extendRouter, }: {
    port: number;
    openapi?: {
        document: Document | RecursivePartial<Document>[];
        handlers: (simulationStore: SimulationStore<ExtendedSimulationSchema, ExtendedSimulationActions>) => Record<string, Handler | Record<string, Handler>>;
        apiRoot?: string;
    };
    extendStore?: {
        schema: ExtendSimulationSchemaInput<ExtendedSimulationSchema>;
        actions: ExtendSimulationActionsInput<ExtendedSimulationActions, ExtendedSimulationSchema>;
    };
    extendRouter?(router: express.Router, simulationStore: SimulationStore<ExtendedSimulationSchema, ExtendedSimulationActions>): void;
}): Promise<{
    listen: (portOverride?: number) => Promise<{
        ensureClose: () => Promise<void>;
        maxHeadersCount: number | null;
        maxRequestsPerSocket: number | null;
        timeout: number;
        headersTimeout: number;
        keepAliveTimeout: number;
        requestTimeout: number;
        maxConnections: number;
        connections: number;
        listening: boolean;
        removeListener<K>(eventName: string | symbol, listener: (...args: any[]) => void): import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
        off<K_1>(eventName: string | symbol, listener: (...args: any[]) => void): import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
        removeAllListeners(eventName?: string | symbol | undefined): import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
        setMaxListeners(n: number): import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
        getMaxListeners(): number;
        listeners<K_2>(eventName: string | symbol): Function[];
        rawListeners<K_3>(eventName: string | symbol): Function[];
        listenerCount<K_4>(eventName: string | symbol, listener?: Function | undefined): number;
        eventNames(): (string | symbol)[];
    }>;
}>;
export declare function startFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions>(arg: Parameters<typeof createFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions>>[0]): Promise<{
    ensureClose: () => Promise<void>;
    maxHeadersCount: number | null;
    maxRequestsPerSocket: number | null;
    timeout: number;
    headersTimeout: number;
    keepAliveTimeout: number;
    requestTimeout: number;
    maxConnections: number;
    connections: number;
    listening: boolean;
    removeListener<K>(eventName: string | symbol, listener: (...args: any[]) => void): import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
    off<K_1>(eventName: string | symbol, listener: (...args: any[]) => void): import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
    removeAllListeners(eventName?: string | symbol | undefined): import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
    setMaxListeners(n: number): import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
    getMaxListeners(): number;
    listeners<K_2>(eventName: string | symbol): Function[];
    rawListeners<K_3>(eventName: string | symbol): Function[];
    listenerCount<K_4>(eventName: string | symbol, listener?: Function | undefined): number;
    eventNames(): (string | symbol)[];
}>;
//# sourceMappingURL=index.d.ts.map